/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.verwaltung;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnittAllgemein;
import de.bsvrz.sys.funclib.bitctrl.util.UndefiniertException;

/**
 * Schnittstelle zur Definition einer Baustelle innerhalb der
 * Baustellensimulation.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface BaustellenSchnittstelle {

	/**
	 * liefert die Anzahl der Fahrstreifen an der angegebenen Stelle in Metern,
	 * ausgehend vom Begin der Baustelle.
	 *
	 * @param position
	 *            die Position, an der die Fahrstreifenanzahl ermittelt werden soll
	 * @return die Anzahl
	 * @throws UndefiniertException
	 *             die Anzahl der Fahrstreifen konnte nicht ermittelt werden.
	 */
	int anzahlFahrStreifen(long position) throws UndefiniertException;

	/**
	 * liefert die für die Baustelle parametrierten Daten.
	 *
	 * @return die Daten
	 */
	BaustellenDatenSchnittstelle getDaten();

	/**
	 * liefert den vor der Baustelle liegenden Messquerschnitt.
	 *
	 * @return den Messquerschnitt
	 * @throws UndefiniertException
	 *             es konnte kein Messquerschnitt ermittelt werden
	 */
	MessQuerschnittAllgemein getMessquerschnittDavor() throws UndefiniertException;

	/**
	 * liefert den Name der Baustelle.<br>
	 * Die Implmentierung des Bausteoleninterfaces liefert hier den Namen, die Pid
	 * oder ide ID des zugeordneten Datenverteiler-Systemobjekts.
	 *
	 * @return den Name
	 */
	String getName();

	/**
	 * liefert das Systemobjekt mit dem die Baustelle in der
	 * Datenverteilerkonfiguration repräsentiert ist.
	 *
	 * @return das Objekt
	 */
	SystemObject getObjekt();

	/**
	 * ermittelt, ob für die Baustelle prinzipiell eine Simulation ausgeführt werden
	 * kann.
	 *
	 * @param manuell
	 *            Simulation manuell ausführen
	 *
	 * @return <b><i>true</i></b>, wenn die Simulation ausgeführt werden kann
	 */
	boolean pruefeSimulierbarkeit(boolean manuell);

	/**
	 * ermittelt die Liste der Stauobjekte, die bei entsprechend den
	 * Simulationsvorgaben entstehen und versendet diese an den Datenverteiler.
	 * 
	 * @param auftrag
	 *            der auszuführende Auftrag
	 */
	void simuliere(SimulationsAuftrag auftrag);
}
